// Load the CSV data
d3.csv(
  'https://raw.githubusercontent.com/Priyanka-Jammigumpula/ICEDataset/main/Titanic.csv',
).then((data) => {
  // Prepare data for the tree structure
  const treeData = {
    name: 'Titanic',
    children: [
      {
        name: 'Survived',
        children: [
          {
            name: 'Survived',
            value: data.filter((d) => d.Survived === '1')
              .length,
          },
          {
            name: 'Not Survived',
            value: data.filter((d) => d.Survived === '0')
              .length,
          },
        ],
      },
    ],
  };

  // Create a tree layout
  const treeLayout = d3.tree().size([600, 400]);

  // Create a root node for the tree
  const rootNode = d3.hierarchy(treeData);

  // Assigns the position for each node
  treeLayout(rootNode);

  // Append an SVG element to the tree div
  const svg = d3
    .select('#tree')
    .append('svg')
    .attr('width', 800)
    .attr('height', 600)
    .append('g')
    .attr('transform', 'translate(50,50)');

  // Draw links between nodes with slimmer lines and different color
  svg
    .selectAll('.link')
    .data(rootNode.links())
    .enter()
    .append('path')
    .attr('class', 'link')
    .attr('stroke', 'lightgrey') // Set line color
    .attr('stroke-width', 1) // Set line width
    .attr(
      'd',
      d3
        .linkHorizontal()
        .x((d) => d.y)
        .y((d) => d.x),
    );

  // Draw nodes
  const node = svg
    .selectAll('.node')
    .data(rootNode.descendants())
    .enter()
    .append('g')
    .attr('class', 'node')
    .attr('transform', (d) => `translate(${d.y},${d.x})`);

  node
    .append('circle')
    .attr('r', 5)
    .attr('fill', 'steelblue'); // Set node color

  node
    .append('text')
    .attr('dy', '.35em')
    .attr('x', (d) => (d.children ? -13 : 13))
    .style('text-anchor', (d) =>
      d.children ? 'end' : 'start',
    )
    .text((d) => d.data.name);

  // Prepare data for the network graph
  const nodes = data.map((d) => ({
    id: d.PassengerId,
    gender: d.Sex,
    age: d.Age,
    pclass: d.Pclass,
  }));

  // Create links between nodes based on some criteria (e.g., same class, same gender)
  const links = [];
  nodes.forEach((source, i) => {
    nodes.forEach((target, j) => {
      if (
        i !== j &&
        source.gender === target.gender &&
        source.age === target.age &&
        source.pclass === target.pclass
      ) {
        links.push({
          source: source.id,
          target: target.id,
        });
      }
    });
  });

  // Create a network simulation
  const simulation = d3
    .forceSimulation(nodes)
    .force(
      'link',
      d3.forceLink(links).id((d) => d.id),
    )
    .force('charge', d3.forceManyBody().strength(-100))
    .force('center', d3.forceCenter(400, 300));

  // Append an SVG element to the graph div
  const svgNetwork = d3
    .select('#graph')
    .append('svg')
    .attr('width', 800)
    .attr('height', 600);

  // Draw links with slimmer lines and different color
  const link = svgNetwork
    .selectAll('.link')
    .data(links)
    .enter()
    .append('line')
    .attr('class', 'link')
    .attr('stroke', 'lightgrey') // Set line color
    .attr('stroke-width', 1); // Set line width

  // Draw nodes with different colors
  const nodeNetwork = svgNetwork
    .selectAll('.node')
    .data(nodes)
    .enter()
    .append('circle')
    .attr('class', 'node')
    .attr('r', 5)
    .attr('fill', (d) =>
      d.gender === 'male' ? 'blue' : 'pink',
    ); // Set node color based on gender

  // Update node positions on each tick of the simulation
  simulation.on('tick', () => {
    link
      .attr('x1', (d) => d.source.x)
      .attr('y1', (d) => d.source.y)
      .attr('x2', (d) => d.target.x)
      .attr('y2', (d) => d.target.y);

    nodeNetwork
      .attr('cx', (d) => d.x)
      .attr('cy', (d) => d.y);
  });
});
